# This file was auto-generated by Fern from our API Definition.

import typing

FilterAttributeType = typing.Union[
    typing.Literal["integer", "real_number", "text", "boolean", "list[integer]", "list[real_number]", "list[text]"],
    typing.Any,
]
