# This file was auto-generated by Fern from our API Definition.

import typing

JobState = typing.Union[
    typing.Literal["unknown", "queued", "started", "completed", "failed", "failed_will_retry", "aborted"], typing.Any
]
