# This file was auto-generated by Fern from our API Definition.

from .max_chars_chunking_strategy import MaxCharsChunkingStrategy

ComponentsSchemasMaxCharsChunkingStrategy = MaxCharsChunkingStrategy
