# This file was auto-generated by Fern from our API Definition.

import typing
from .rephrase_span import RephraseSpan
from .search_span import SearchSpan
from .rerank_span import RerankSpan
from .generation_span import GenerationSpan
from .factual_consistency_score_span import FactualConsistencyScoreSpan

QueryHistorySpan = typing.Union[RephraseSpan, SearchSpan, RerankSpan, GenerationSpan, FactualConsistencyScoreSpan]
